@@ -220,6 +220,23 @@ class CustomDatasetV2(CustomDataset):
         return np.expand_dims(oversample_patch_images , axis = 0), np.expand_dims(oversample_patch_seg , axis = 0)
     """
     
+    def pad_image_seg(self, images, seg): #patch size보다 전체 이미지 크기가 작을 경우 padding을 진행
+        if isinstance(images, np.ndarray):
+            images = torch.tensor(images.copy())
+        if isinstance(seg, np.ndarray):
+            seg = torch.tensor(seg.copy())
+        image_shape = np.array(images[0].shape)
+        if np.any(image_shape < self.patch_size):
+            odd_pad = ((self.patch_size - image_shape) % 2 != 0).astype(int)
+            even_pad = np.repeat(np.clip(((self.patch_size - image_shape)/2).astype(int), 0, np.inf), 2)
+            for i in range(len(odd_pad)):
+                even_pad[i*2] += odd_pad[i]
+            even_pad = tuple(even_pad[::-1].astype(int).copy())
+            images = F.pad(images, even_pad, "constant", 0 )
+            seg = F.pad(seg, even_pad, "constant", 0 )
+
+        return images, seg
+
     def __getitem__(self, idx):
         info_file = open(os.path.join(self.root_dir,self.info_name[idx]), 'rb')
         info_data = pickle.load(info_file)
@@ -256,7 +273,7 @@ class CustomDatasetV2(CustomDataset):
             else:
                 x = self.resample(x, info_data)
         
-
+        x, y = self.pad_image_seg(x, y)
         if self.batch_size == 1 :
             result_images, result_seg = self.get_normal_patch(x, y)
 
